@@ -6,7 +6,7 @@ from pysilico_server.devices.simulated_camera import \
 from pysilico_server.devices.simulated_auxiliary_camera import \
     SimulatedAuxiliaryCamera
 from plico.utils.logger import Logger
-from plico.utils.control_loop import FaultTolerantControlLoop
+from plico.utils.control_loop import IntolerantControlLoop
 from plico.utils.decorator import override
 from pysilico_server.camera_controller.camera_controller import \
     CameraController
@@ -30,11 +30,13 @@ def ContextWrapper():
             try:
                 with vimba.Vimba.get_instance():
                     if hasattr(self, '_vimbacamera'):
-                       with self._vimbacamera:
+                        with self._vimbacamera:
                             return f(self, *args, **kwds)
                     else:
                         return f(self, *args, **kwds)
-            except vimba.error.VimbaCameraError as e:
+            except (vimba.error.VimbaCameraError,
+                    vimba.c_binding.vimba_common.VimbaCError,
+                    vimba.error.VimbaFeatureError) as e:
                 raise CameraException(e.__str__())
 
         def wrapper_generic(self, *args, **kwds):
@@ -151,7 +153,7 @@ class Runner(BaseRunner):
         self._logRunning()
 
         self._camera.startAcquisition()
-        FaultTolerantControlLoop(
+        IntolerantControlLoop(
             self._controller,
             Logger.of("Camera Controller control loop"),
             time,
@@ -168,10 +170,12 @@ class Runner(BaseRunner):
             except CameraException as e:
                 # Camera unreachable or other errors
                 # Wait a little bit and try to reconnect
-                print(e)
+                self._logger.warn(e)
+                if hasattr(self, '_vimbacamera'):
+                    delattr(self, '_vimbacamera')
                 time.sleep(1)
             except Exception as e:
-                print('Unhandled exception: '+str(e))
+                self._logger.fatal('Unhandled exception: '+str(e))
                 self._isTerminated = True
         return os.EX_OK
 
