@@ -10,8 +10,7 @@ __version__= "$Id: tipico_kill_processes.py 31 2018-01-27 10:47:29Z lbusoni $"
 def main():
     logging.basicConfig(level=logging.INFO)
     processNames= [Constants.START_PROCESS_NAME,
-                   Constants.SERVER_1_PROCESS_NAME,
-                   Constants.SERVER_2_PROCESS_NAME,
+                   Constants.SERVER_PROCESS_NAME,
                    ]
 
     for each in processNames:
