@@ -8,12 +8,10 @@ class Constants:
     THIS_PACKAGE= 'pysilico_server'
 
     PROCESS_MONITOR_CONFIG_SECTION= 'processMonitor'
-    SERVER_1_CONFIG_SECTION= 'avt1'
-    SERVER_2_CONFIG_SECTION= 'avt2'
+    SERVER_CONFIG_SECTION_PREFIX= 'camera'
 
     # TODO: must be the same of console_scripts in setup.py
     START_PROCESS_NAME= 'pysilico_start'
     STOP_PROCESS_NAME= 'pysilico_stop'
     KILL_ALL_PROCESS_NAME= 'pysilico_kill_all'
-    SERVER_1_PROCESS_NAME= 'pysilico_server_1'
-    SERVER_2_PROCESS_NAME= 'pysilico_server_2'
+    SERVER_PROCESS_NAME= 'pysilico_server'
